@@ -34,5 +34,14 @@ char * dm_obtain_grandparent_host(void);
 int dm_remove_last_route_to(void);
 void dm_randomly_change_route_to (dm_machinelist_information * m, const dm_commandoption * cdat);
 
+char *dm_get_lastitem (const char * ch);
+char *dm_get_firstitem (const char * ch);
+char *dm_get_itemsexceptlast (const char * ch);
+char *dm_get_itemsexceptfirst (const char * ch);
+
+
+
+
+
 #endif
 
