@@ -22,10 +22,22 @@
 #ifndef __DMACHINEMON_H
 #define __DMACHINEMON_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+  
 #include <dmachinemon/dmachinemon-libdatabase.h>
 #include <dmachinemon/dmachinemon-commandlineparser.h>
 #include <dmachinemon/dmachinemon-libnodeinfo.h>
 #include <dmachinemon/libsocket.h>
 #include <dmachinemon/dmachinemon-servent-libroute.h>
 #include <dmachinemon/dmachinemon-libp2papplication.h>
+#include <dmachinemon/dmachinemon-daemonize.h>
+#include <dmachinemon/dnas-connect-to-host.h>
+
+#ifdef __cplusplus
+}
+#endif
+
+
 #endif
